@@ -75,6 +75,7 @@ fn handle_playback_subcommand(args: &ArgMatches) -> Result<Request> {
     let (cmd, args) = args.subcommand().expect("playback subcommand is required");
     let command = match cmd {
         "start" => match args.subcommand() {
+            Some(("track", args)) => Command::StartTrack(get_id_or_name(args)),
             Some(("context", args)) => {
                 let context_type = args
                     .get_one::<ContextType>("context_type")
@@ -180,8 +181,7 @@ pub fn handle_cli_subcommand(cmd: &str, args: &ArgMatches) -> Result<()> {
     match cmd {
         "authenticate" => {
             let auth_config = AuthConfig::new(configs)?;
-            let rt = tokio::runtime::Runtime::new()?;
-            rt.block_on(crate::auth::get_creds(&auth_config, true, false))?;
+            crate::auth::get_creds(&auth_config, true, false)?;
             std::process::exit(0);
         }
         "generate" => {
