@@ -128,9 +128,7 @@ impl Client {
     /// Create a new client session
     pub async fn new_session(&self, state: Option<&SharedState>, reauth: bool) -> Result<()> {
         let session = self.auth_config.session();
-        let creds = auth::get_creds(&self.auth_config, reauth, true)
-            .await
-            .context("get credentials")?;
+        let creds = auth::get_creds(&self.auth_config, reauth, true).context("get credentials")?;
         *self.session.lock().await = Some(session.clone());
 
         #[allow(unused_mut)]
@@ -303,7 +301,7 @@ impl Client {
             PlayerRequest::TransferPlayback(..) => {
                 anyhow::bail!("`TransferPlayback` should be handled earlier")
             }
-        };
+        }
 
         Ok(Some(playback))
     }
@@ -594,7 +592,7 @@ impl Client {
                 )
                 .await?;
             }
-        };
+        }
 
         tracing::info!(
             "Successfully handled the client request, took: {}ms",
@@ -778,6 +776,7 @@ impl Client {
     pub async fn current_user_playlists(&self) -> Result<Vec<Playlist>> {
         // TODO: this should use `rspotify::current_user_playlists_manual` API instead of `internal_call`
         // See: https://github.com/ramsayleung/rspotify/issues/459
+        // Fetch the first page of playlists
         let first_page = self
             .http_get::<rspotify::model::Page<rspotify::model::SimplifiedPlaylist>>(
                 &format!("{SPOTIFY_API_ENDPOINT}/me/playlists"),
@@ -789,7 +788,9 @@ impl Client {
         //     .current_user_playlists_manual(Some(50), None)
         //     .await?;
 
+        // Fetch all pages of playlists
         let playlists = self.all_paging_items(first_page, &Query::new()).await?;
+
         Ok(playlists
             .into_iter()
             .map(std::convert::Into::into)
@@ -832,8 +833,8 @@ impl Client {
 
         let albums = self.all_paging_items(first_page, &Query::new()).await?;
 
-        // converts `rspotify::model::SavedAlbum` into `state::Album`
-        Ok(albums.into_iter().map(|a| a.album.into()).collect())
+        // Converts `rspotify::model::SavedAlbum` into `state::Album`
+        Ok(albums.into_iter().map(Album::from).collect())
     }
 
     /// Get all saved shows of the current user
@@ -916,6 +917,15 @@ impl Client {
 
     /// Get recommendation (radio) tracks based on a seed
     pub async fn radio_tracks(&self, seed_uri: String) -> Result<Vec<Track>> {
+        #[derive(Debug, Deserialize)]
+        struct TrackData {
+            original_gid: String,
+        }
+        #[derive(Debug, Deserialize)]
+        struct RadioStationResponse {
+            tracks: Vec<TrackData>,
+        }
+
         let session = self.session().await;
 
         // Get an autoplay URI from the seed URI.
@@ -948,14 +958,6 @@ impl Client {
             );
         }
 
-        #[derive(Debug, Deserialize)]
-        struct TrackData {
-            original_gid: String,
-        }
-        #[derive(Debug, Deserialize)]
-        struct RadioStationResponse {
-            tracks: Vec<TrackData>,
-        }
         // Parse a list consisting of IDs of tracks inside the radio station
         let track_ids = serde_json::from_slice::<RadioStationResponse>(&response.payload[0])?
             .tracks
@@ -1380,6 +1382,7 @@ impl Client {
             .filter_map(Track::try_from_full_track)
             .collect::<Vec<_>>();
 
+        #[allow(deprecated)]
         let related_artists = self
             .artist_related_artists(artist_id.as_ref())
             .await
@@ -1410,6 +1413,18 @@ impl Client {
         let show = self.get_a_show(show_id, None).await?;
         let first_page = show.episodes.clone();
 
+        // Copy first_page but use Page<Option<SimplifiedEpisode>> instead of Page<SimplifiedEpisode>
+        // This is a temporary fix for https://github.com/aome510/spotify-player/issues/663
+        let first_page = rspotify::model::Page {
+            items: first_page.items.into_iter().map(Some).collect(),
+            href: first_page.href,
+            limit: first_page.limit,
+            next: first_page.next,
+            offset: first_page.offset,
+            previous: first_page.previous,
+            total: first_page.total,
+        };
+
         // converts `rspotify::model::FullShow` into `state::Show`
         let show: Show = show.into();
 
@@ -1418,6 +1433,7 @@ impl Client {
             .all_paging_items(first_page, &Query::new())
             .await?
             .into_iter()
+            .flatten()
             .map(std::convert::Into::into)
             .collect::<Vec<_>>();
 
@@ -1667,7 +1683,7 @@ impl Client {
 
         #[cfg(all(feature = "notify", not(feature = "streaming")))]
         if configs.app_config.enable_notify {
-            Self::notify_new_track(&track, &path)?;
+            Self::notify_new_playback(&curr_item, &path)?;
         }
 
         Ok(())
@@ -1752,7 +1768,7 @@ impl Client {
                             text += &episode.show.name;
                         }
                     },
-                    _ => continue,
+                    &_ => {}
                 }
             }
             if ptr < format_str.len() {
@@ -1819,12 +1835,24 @@ impl Client {
 
     /// Process a list of albums, which includes
     /// - sort albums by the release date
+    /// - sort albums by the type if `sort_artist_albums_by_type` config is enabled
     fn process_artist_albums(albums: Vec<Album>) -> Vec<Album> {
         let mut albums = albums.into_iter().collect::<Vec<_>>();
 
-        albums.sort_by(|x, y| x.release_date.partial_cmp(&y.release_date).unwrap());
+        albums.sort_by(|x, y| y.release_date.partial_cmp(&x.release_date).unwrap());
 
-        albums.reverse();
+        if config::get_config().app_config.sort_artist_albums_by_type {
+            fn get_priority(album_type: &str) -> usize {
+                match album_type {
+                    "album" => 0,
+                    "single" => 1,
+                    "appears_on" => 2,
+                    "compilation" => 3,
+                    _ => 4,
+                }
+            }
+            albums.sort_by_key(|a| get_priority(&a.album_type()));
+        }
 
         albums
     }
