@@ -300,6 +300,14 @@ impl Default for KeymapConfig {
                     key_sequence: "s r".into(),
                     command: Command::ReverseTrackOrder,
                 },
+                Keymap {
+                    key_sequence: "s l a".into(),
+                    command: Command::SortLibraryAlphabetically,
+                },
+                Keymap {
+                    key_sequence: "s l r".into(),
+                    command: Command::SortLibraryByRecent,
+                },
                 Keymap {
                     key_sequence: "C-k".into(),
                     command: Command::MovePlaylistItemUp,
