@@ -238,7 +238,7 @@ fn handle_playlist_modify_command(
                     snapshot_id: None,
                 })?;
                 ui.current_page_mut().select(id + 1);
-            };
+            }
             return Ok(true);
         }
         Command::ShowActionsOnSelectedItem => {
@@ -290,16 +290,21 @@ fn handle_command_for_track_table_window(
         }
     }
 
-    if handle_navigation_command(command, ui.current_page_mut(), id, filtered_tracks.len()) {
+    let count = ui.count_prefix;
+    if handle_navigation_command(
+        command,
+        ui.current_page_mut(),
+        id,
+        filtered_tracks.len(),
+        count,
+    ) {
         return Ok(true);
     }
 
     match command {
         Command::PlayRandom | Command::ChooseSelected => {
             let uri = if command == Command::PlayRandom {
-                tracks[rand::thread_rng().gen_range(0..tracks.len())]
-                    .id
-                    .uri()
+                tracks[rand::rng().random_range(0..tracks.len())].id.uri()
             } else {
                 filtered_tracks[id].id.uri()
             };
@@ -349,7 +354,8 @@ pub fn handle_command_for_track_list_window(
         return Ok(false);
     }
 
-    if handle_navigation_command(command, ui.current_page_mut(), id, tracks.len()) {
+    let count = ui.count_prefix;
+    if handle_navigation_command(command, ui.current_page_mut(), id, tracks.len(), count) {
         return Ok(true);
     }
     match command {
@@ -392,7 +398,8 @@ pub fn handle_command_for_artist_list_window(
         return false;
     }
 
-    if handle_navigation_command(command, ui.current_page_mut(), id, artists.len()) {
+    let count = ui.count_prefix;
+    if handle_navigation_command(command, ui.current_page_mut(), id, artists.len(), count) {
         return true;
     }
     match command {
@@ -428,7 +435,8 @@ pub fn handle_command_for_album_list_window(
         return Ok(false);
     }
 
-    if handle_navigation_command(command, ui.current_page_mut(), id, albums.len()) {
+    let count = ui.count_prefix;
+    if handle_navigation_command(command, ui.current_page_mut(), id, albums.len(), count) {
         return Ok(true);
     }
     match command {
@@ -466,7 +474,8 @@ pub fn handle_command_for_playlist_list_window(
         return false;
     }
 
-    if handle_navigation_command(command, ui.current_page_mut(), id, playlists.len()) {
+    let count = ui.count_prefix;
+    if handle_navigation_command(command, ui.current_page_mut(), id, playlists.len(), count) {
         return true;
     }
     match command {
@@ -482,7 +491,7 @@ pub fn handle_command_for_playlist_list_window(
                             state.playlist_folder_id = f.target_id;
                         }
                         _ => return false,
-                    };
+                    }
                 }
                 PlaylistFolderItem::Playlist(p) => {
                     let context_id = ContextId::Playlist(p.id.clone());
@@ -519,7 +528,8 @@ pub fn handle_command_for_show_list_window(
         return false;
     }
 
-    if handle_navigation_command(command, ui.current_page_mut(), id, shows.len()) {
+    let count = ui.count_prefix;
+    if handle_navigation_command(command, ui.current_page_mut(), id, shows.len(), count) {
         return true;
     }
     match command {
@@ -555,7 +565,8 @@ pub fn handle_command_for_episode_list_window(
         return Ok(false);
     }
 
-    if handle_navigation_command(command, ui.current_page_mut(), id, episodes.len()) {
+    let count = ui.count_prefix;
+    if handle_navigation_command(command, ui.current_page_mut(), id, episodes.len(), count) {
         return Ok(true);
     }
     match command {
@@ -595,7 +606,8 @@ fn handle_command_for_episode_table_window(
         return Ok(false);
     }
 
-    if handle_navigation_command(command, ui.current_page_mut(), id, episodes.len()) {
+    let count = ui.count_prefix;
+    if handle_navigation_command(command, ui.current_page_mut(), id, episodes.len(), count) {
         return Ok(true);
     }
     match command {
