@@ -1,11 +1,12 @@
+use crate::utils::map_join;
+use html_escape::decode_html_entities;
 pub use rspotify::model::{
     AlbumId, ArtistId, EpisodeId, Id, PlayableId, PlaylistId, ShowId, TrackId, UserId,
 };
-
-use crate::utils::map_join;
-use html_escape::decode_html_entities;
 use serde::{Deserialize, Serialize};
 use std::borrow::Cow;
+use std::fmt::Write;
+use unicode_bidi::BidiInfo;
 
 #[derive(Serialize, Clone, Debug)]
 #[serde(untagged)]
@@ -146,7 +147,8 @@ pub struct Album {
     pub release_date: String,
     pub name: String,
     pub artists: Vec<Artist>,
-    pub album_type: Option<rspotify::model::AlbumType>,
+    pub typ: Option<rspotify::model::AlbumType>,
+    pub added_at: u64,
 }
 
 #[derive(Deserialize, Serialize, Debug, Clone)]
@@ -167,6 +169,7 @@ pub struct Playlist {
     /// which folder id the playlist refers to
     #[serde(default)]
     pub current_folder_id: usize,
+    pub snapshot_id: String,
 }
 
 #[derive(Deserialize, Serialize, Debug, Clone)]
@@ -205,7 +208,7 @@ pub enum PlaylistFolderItem {
 }
 
 #[derive(Deserialize, Debug, Clone)]
-/// A reference node retrieved by running https://github.com/mikez/spotify-folders
+/// A reference node retrieved by running <https://github.com/mikez/spotify-folders>
 /// Helps building a playlist folder hierarchy
 pub struct PlaylistFolderNode {
     pub name: Option<String>,
@@ -232,22 +235,26 @@ impl Context {
                 ref album,
                 ref tracks,
             } => {
+                let album_length = play_time(tracks);
                 format!(
-                    "{} | {} | {} songs",
+                    "{} | {} | {} songs | {}",
                     album.name,
                     album.release_date,
-                    tracks.len()
+                    tracks.len(),
+                    album_length,
                 )
             }
             Context::Playlist {
                 ref playlist,
                 tracks,
             } => {
+                let playlist_length = play_time(tracks);
                 format!(
-                    "{} | {} | {} songs",
+                    "{} | {} | {} songs | {}",
                     playlist.name,
                     playlist.owner.0,
-                    tracks.len()
+                    tracks.len(),
+                    playlist_length,
                 )
             }
             Context::Artist { ref artist, .. } => artist.name.to_string(),
@@ -260,6 +267,31 @@ impl Context {
     }
 }
 
+fn play_time(tracks: &[Track]) -> String {
+    let duration = tracks
+        .iter()
+        .map(|t| t.duration)
+        .sum::<std::time::Duration>();
+
+    let mut output = String::new();
+
+    let seconds = duration.as_secs() % 60;
+    let minutes = (duration.as_secs() / 60) % 60;
+    let hours = duration.as_secs() / 3600;
+
+    if hours > 0 {
+        write!(output, "{hours}h ").unwrap();
+    }
+
+    if minutes > 0 {
+        write!(output, "{minutes}m ").unwrap();
+    }
+
+    write!(output, "{seconds}s").unwrap();
+
+    output
+}
+
 impl ContextId {
     pub fn uri(&self) -> String {
         match self {
@@ -338,7 +370,7 @@ impl Track {
         }
     }
 
-    /// tries to convert from a `rspotify::model::FullTrack` into `Track` with a optional added_at date
+    /// tries to convert from a `rspotify::model::FullTrack` into `Track` with a optional `added_at` date
     fn try_from_full_track_with_date(
         track: rspotify::model::FullTrack,
         added_at: Option<chrono::DateTime<chrono::Utc>>,
@@ -397,7 +429,7 @@ impl Album {
             name: album.name,
             release_date: album.release_date.unwrap_or_default(),
             artists: from_simplified_artists_to_artists(album.artists),
-            album_type: album
+            typ: album
                 .album_type
                 .and_then(|t| match t.to_ascii_lowercase().as_str() {
                     "album" => Some(rspotify::model::AlbumType::Album),
@@ -406,6 +438,7 @@ impl Album {
                     "compilation" => Some(rspotify::model::AlbumType::Compilation),
                     _ => None,
                 }),
+            added_at: 0,
         })
     }
 
@@ -420,7 +453,7 @@ impl Album {
 
     /// gets the album type
     pub fn album_type(&self) -> String {
-        match self.album_type {
+        match self.typ {
             Some(t) => <&str>::from(t).to_string(),
             _ => String::new(),
         }
@@ -434,11 +467,20 @@ impl From<rspotify::model::FullAlbum> for Album {
             id: album.id,
             release_date: album.release_date,
             artists: from_simplified_artists_to_artists(album.artists),
-            album_type: Some(album.album_type),
+            typ: Some(album.album_type),
+            added_at: 0,
         }
     }
 }
 
+impl From<rspotify::model::SavedAlbum> for Album {
+    fn from(saved_album: rspotify::model::SavedAlbum) -> Self {
+        let mut album: Album = saved_album.album.into();
+        album.added_at = saved_album.added_at.timestamp() as u64;
+        album
+    }
+}
+
 impl std::fmt::Display for Album {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         write!(
@@ -499,6 +541,7 @@ impl From<rspotify::model::SimplifiedPlaylist> for Playlist {
             ),
             desc: String::new(),
             current_folder_id: 0,
+            snapshot_id: playlist.snapshot_id,
         }
     }
 }
@@ -520,6 +563,7 @@ impl From<rspotify::model::FullPlaylist> for Playlist {
             ),
             desc,
             current_folder_id: 0,
+            snapshot_id: playlist.snapshot_id,
         }
     }
 }
@@ -694,7 +738,20 @@ impl From<librespot_metadata::lyrics::Lyrics> for Lyrics {
                 let t = chrono::Duration::milliseconds(
                     l.start_time_ms.parse::<i64>().expect("invalid number"),
                 );
-                (t, l.words)
+
+                // Some songs use multiple languages and may contain a mix of rtl and ltr text.
+                // Therefore rtl formatting needs to be done on a per-line basis.
+                let bidi_info = BidiInfo::new(&l.words, None);
+
+                let words = if bidi_info.has_rtl() && !bidi_info.paragraphs.is_empty() {
+                    bidi_info
+                        .reorder_line(&bidi_info.paragraphs[0], 0..l.words.len())
+                        .into_owned()
+                } else {
+                    l.words
+                };
+
+                (t, words)
             })
             .collect::<Vec<_>>();
         lines.sort_by_key(|l| l.0);
