@@ -3,7 +3,7 @@ use std::{
     fmt::Display,
 };
 
-use tui::text::Line;
+use ratatui::text::Line;
 
 use crate::{state::Episode, utils::format_duration};
 
@@ -35,6 +35,10 @@ pub fn render_search_page(
     ui: &mut UIStateGuard,
     rect: Rect,
 ) {
+    fn search_items<T: Display>(items: &[T]) -> Vec<(String, bool)> {
+        items.iter().map(|i| (i.to_string(), false)).collect()
+    }
+
     // 1. Get data
     let data = state.data.read();
 
@@ -112,17 +116,17 @@ pub fn render_search_page(
     let show_rect = construct_and_render_block(
         "Shows",
         &ui.theme,
-        Borders::TOP | Borders::RIGHT,
+        if ui.orientation == Orientation::Horizontal {
+            Borders::TOP | Borders::RIGHT
+        } else {
+            Borders::TOP
+        },
         frame,
         chunks[4],
     );
     let episode_rect =
         construct_and_render_block("Episodes", &ui.theme, Borders::TOP, frame, chunks[5]);
 
-    fn search_items<T: Display>(items: &[T]) -> Vec<(String, bool)> {
-        items.iter().map(|i| (i.to_string(), false)).collect()
-    }
-
     // 3. Construct the page's widgets
     let (track_list, n_tracks) = {
         let track_items = search_results
@@ -285,8 +289,23 @@ pub fn render_context_page(
         Some(context) => {
             // render context description
             let chunks = Layout::vertical([Constraint::Length(1), Constraint::Fill(0)]).split(rect);
+            let is_followed_string = if let Context::Playlist { playlist, .. } = context {
+                if data.user_data.is_followed_playlist(playlist) {
+                    "Followed"
+                } else {
+                    "Not Followed"
+                }
+            } else {
+                ""
+            };
+
             frame.render_widget(
-                Paragraph::new(context.description()).style(ui.theme.page_desc()),
+                Paragraph::new(format!(
+                    "{} | {}",
+                    context.description(),
+                    is_followed_string
+                ))
+                .style(ui.theme.page_desc()),
                 chunks[0],
             );
             let rect = chunks[1];
@@ -552,10 +571,6 @@ pub fn render_lyrics_page(
     rect: Rect,
 ) {
     // 1. Get data
-    let Some(progress) = state.player.read().playback_progress() else {
-        frame.render_widget(Paragraph::new("Lyrics not found"), rect);
-        return;
-    };
     let data = state.data.read();
 
     // 2. Construct the page's layout
@@ -563,6 +578,11 @@ pub fn render_lyrics_page(
     let chunks = Layout::vertical([Constraint::Length(2), Constraint::Fill(0)]).split(rect);
 
     // 3. Construct the page's widgets
+    let Some(progress) = state.player.read().playback_progress() else {
+        frame.render_widget(Paragraph::new("No playback available"), rect);
+        return;
+    };
+
     let PageState::Lyrics {
         track_uri,
         track,
@@ -605,12 +625,10 @@ pub fn render_lyrics_page(
         .lines
         .iter()
         .enumerate()
-        .map(|(id, (_, line))| {
-            if id < last_played_line_id {
-                Line::styled(line, ui.theme.lyrics_played())
-            } else {
-                Line::raw(line)
-            }
+        .map(|(id, (_, line))| match (id + 1).cmp(&last_played_line_id) {
+            std::cmp::Ordering::Less => Line::styled(line, ui.theme.lyrics_played()),
+            std::cmp::Ordering::Equal => Line::styled(line, ui.theme.lyrics_playing()),
+            std::cmp::Ordering::Greater => Line::raw(line),
         })
         .collect::<Vec<_>>();
 
@@ -829,6 +847,7 @@ fn render_artist_context_page_windows(
 
     // 3. Construct the page's widgets
     // album table
+
     let is_albums_active = is_active && focus_state == ArtistFocusState::Albums;
     let n_albums = albums.len();
     let album_rows = albums
